[jboss-cvs] JBossCache/tests-50/functional/org/jboss/cache/pojo/test ...
Ben Wang
bwang at jboss.com
Tue Nov 21 01:07:35 EST 2006
User: bwang
Date: 06/11/21 01:07:35
Modified: tests-50/functional/org/jboss/cache/pojo/test
ArrayObject.java SpecialAddress.java
NetworkAdmin.java Link.java NodeManager.java
TestNode.java Address.java Person.java
NetworkDomain.java ValueObject.java Resource.java
NetworkElement.java EnumPlanet.java
SpecialSerializedAddress.java NetworkNode.java
IdObject.java Gadget.java
Log:
JBCACHE-868 Renaming PojoCache annotation.
Revision Changes Path
1.2 +1 -1 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/ArrayObject.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: ArrayObject.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/ArrayObject.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -b -r1.1 -r1.2
--- ArrayObject.java 5 Aug 2006 04:13:25 -0000 1.1
+++ ArrayObject.java 21 Nov 2006 06:07:34 -0000 1.2
@@ -10,7 +10,7 @@
/**
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.InstanceOfPojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class ArrayObject
{
private Person[] team;
1.2 +2 -2 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/SpecialAddress.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: NetworkAdmin.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NetworkAdmin.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- NetworkAdmin.java 25 Aug 2006 14:10:11 -0000 1.3
+++ NetworkAdmin.java 21 Nov 2006 06:07:34 -0000 1.4
@@ -14,7 +14,7 @@
* @author <a href="mailto:ben.wang at jboss.com">Ben Wang</a>
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class NetworkAdmin
{
String id_;
1.4 +2 -2 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Link.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: Link.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Link.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- Link.java 7 Jul 2006 10:38:28 -0000 1.3
+++ Link.java 21 Nov 2006 06:07:34 -0000 1.4
@@ -11,14 +11,14 @@
* Test class for PojoCache for circular references.
* Link is a POJO that will be instrumentet with CacheFieldInterceptor
*
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.4 $
* <p>Below is the annotation that signifies this class is "prepared" under JBossAop. This is used in
* conjunction with a special jboss-aop.xml (supplied by JBossCache). In addition, this is JDK1.4 style,
* so a annoc Ant build target is needed to pre-compile it.</p>
* <p>To use this approach, just apply this line to your pojo and run annoc (and possibly aopc).</p>
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class Link
{
Link link_;
1.4 +2 -2 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NodeManager.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: NodeManager.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NodeManager.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- NodeManager.java 7 Jul 2006 10:38:28 -0000 1.3
+++ NodeManager.java 21 Nov 2006 06:07:34 -0000 1.4
@@ -15,14 +15,14 @@
* Test class for PojoCache for circular references.
* Link is a POJO that will be instrumentet with CacheFieldInterceptor
*
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.4 $
* <p>Below is the annotation that signifies this class is "prepared" under JBossAop. This is used in
* conjunction with a special jboss-aop.xml (supplied by JBossCache). In addition, this is JDK1.4 style,
* so a annoc Ant build target is needed to pre-compile it.</p>
* <p>To use this approach, just apply this line to your pojo and run annoc (and possibly aopc).</p>
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class NodeManager
{
private TestNode rootNode_;
1.3 +1 -1 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/TestNode.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: TestNode.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/TestNode.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- TestNode.java 27 Jun 2006 09:19:31 -0000 1.2
+++ TestNode.java 21 Nov 2006 06:07:34 -0000 1.3
@@ -3,7 +3,7 @@
import java.util.ArrayList;
import java.util.List;
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class TestNode
{
private String rdn_;
1.4 +2 -2 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Address.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: Address.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Address.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- Address.java 8 Jul 2006 17:31:52 -0000 1.3
+++ Address.java 21 Nov 2006 06:07:34 -0000 1.4
@@ -10,14 +10,14 @@
/**
* Test class for PojoCache.
*
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.4 $
* <p>Below is the annotation that signifies this class is "prepared" under JBossAop. This is used in
* conjunction with a special jboss-aop.xml (supplied by JBossCache). In addition, this is JDK1.4 style,
* so a annoc Ant build target is needed to pre-compile it.</p>
* <p>To use this approach, just apply this line to your pojo and run annoc (and possibly aopc).</p>
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class Address
{
String street = null;
1.4 +2 -2 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Person.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: Person.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Person.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- Person.java 7 Jul 2006 10:38:28 -0000 1.3
+++ Person.java 21 Nov 2006 06:07:34 -0000 1.4
@@ -17,14 +17,14 @@
* Test class for PojoCache.
* Person is a POJO that will be instrumented with CacheFieldInterceptor
*
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.4 $
* <p>Below is the annotation that signifies this class is "prepared" under JBossAop. This is used in
* conjunction with a special jboss-aop.xml (supplied by PojoCache). In addition, this is JDK1.4 style,
* so a annoc Ant build target is needed to pre-compile it.</p>
* <p>To use this approach, just apply this line to your pojo and run annoc (and possibly aopc).</p>
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.InstanceOfPojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class Person
{
String name = null;
1.3 +1 -1 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NetworkDomain.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: NetworkDomain.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NetworkDomain.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- NetworkDomain.java 27 Jun 2006 09:19:31 -0000 1.2
+++ NetworkDomain.java 21 Nov 2006 06:07:34 -0000 1.3
@@ -18,7 +18,7 @@
* @author <a href="mailto:ben.wang at jboss.com">Ben Wang</a>
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class NetworkDomain
{
String name_;
1.3 +1 -1 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/ValueObject.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: ValueObject.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/ValueObject.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- ValueObject.java 27 Jun 2006 09:19:31 -0000 1.2
+++ ValueObject.java 21 Nov 2006 06:07:34 -0000 1.3
@@ -10,7 +10,7 @@
* Object to test non-primitive key.
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.InstanceOfPojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class ValueObject
{
1.4 +3 -5 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Resource.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: NetworkElement.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NetworkElement.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- NetworkElement.java 25 Aug 2006 14:10:11 -0000 1.3
+++ NetworkElement.java 21 Nov 2006 06:07:34 -0000 1.4
@@ -16,7 +16,7 @@
* @author <a href="mailto:ben.wang at jboss.com">Ben Wang</a>
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class NetworkElement
{
// Unique id
1.2 +2 -2 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/EnumPlanet.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: EnumPlanet.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/EnumPlanet.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -b -r1.1 -r1.2
--- EnumPlanet.java 8 Nov 2006 08:48:51 -0000 1.1
+++ EnumPlanet.java 21 Nov 2006 06:07:34 -0000 1.2
@@ -25,14 +25,14 @@
/**
* Test class for PojoCache Enum.
*
- * @version $Revision: 1.1 $
+ * @version $Revision: 1.2 $
* <p>Below is the annotation that signifies this class is "prepared" under JBossAop. This is used in
* conjunction with a special jboss-aop.xml (supplied by JBossCache). In addition, this is JDK1.4 style,
* so a annoc Ant build target is needed to pre-compile it.</p>
* <p>To use this approach, just apply this line to your pojo and run annoc (and possibly aopc).</p>
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public enum EnumPlanet
{
MERCURY(3.303e+23, 2.4397e6),
1.3 +2 -2 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/SpecialSerializedAddress.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: SpecialSerializedAddress.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/SpecialSerializedAddress.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- SpecialSerializedAddress.java 27 Jun 2006 09:19:31 -0000 1.2
+++ SpecialSerializedAddress.java 21 Nov 2006 06:07:35 -0000 1.3
@@ -14,9 +14,9 @@
/**
* Test class for PojoCache.
*
- * @version $Revision: 1.2 $
+ * @version $Revision: 1.3 $
*/
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class SpecialSerializedAddress implements Serializable
{
String street = null;
1.3 +1 -1 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NetworkNode.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: NetworkNode.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NetworkNode.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- NetworkNode.java 27 Jun 2006 09:19:31 -0000 1.2
+++ NetworkNode.java 21 Nov 2006 06:07:35 -0000 1.3
@@ -17,7 +17,7 @@
* @author <a href="mailto:ben.wang at jboss.com">Ben Wang</a>
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class NetworkNode
{
String name_;
1.3 +1 -1 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/IdObject.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: IdObject.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/IdObject.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- IdObject.java 27 Jun 2006 09:19:31 -0000 1.2
+++ IdObject.java 21 Nov 2006 06:07:35 -0000 1.3
@@ -10,7 +10,7 @@
* Key object that overrides the hashCode that can cause problem for aop.
*/
// We are using JDK1.5 annotation.
- at org.jboss.cache.pojo.annotation.InstanceOfPojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class IdObject
{
1.4 +2 -2 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Gadget.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: Gadget.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Gadget.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- Gadget.java 20 Sep 2006 08:50:06 -0000 1.3
+++ Gadget.java 21 Nov 2006 06:07:35 -0000 1.4
@@ -14,9 +14,9 @@
* Test class for PojoCache using annotation. This object consists of sub-objects
* that has special annotation.
*
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.4 $
*/
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class Gadget
{
String name;
More information about the jboss-cvs-commits
mailing list
Index: SpecialAddress.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/SpecialAddress.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -b -r1.1 -r1.2
--- SpecialAddress.java 22 Jun 2006 12:35:09 -0000 1.1
+++ SpecialAddress.java 21 Nov 2006 06:07:34 -0000 1.2
@@ -10,12 +10,12 @@
import java.io.Serializable;
/**
* Test class for PojoCache. Note that this pojo is both PojoCacheable and Serializable. So
* user can choose whether to treat this as a Pojo or just a serializable object.
*
- * @version $Revision: 1.1 $
+ * @version $Revision: 1.2 $
*/
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class SpecialAddress implements Serializable
{
String addr = null;
@@ -10,12 +10,12 @@
import java.io.Serializable;
/**
- * Test class for PojoCache. Note that this pojo is both PojoCacheable and Serializable. So
+ * Test class for PojoCache. Note that this pojo is both Replicable and Serializable. So
* user can choose whether to treat this as a Pojo or just a serializable object.
*
1.4 +1 -1 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NetworkAdmin.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: Resource.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests-50/functional/org/jboss/cache/pojo/test/Resource.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- Resource.java 31 Oct 2006 04:33:55 -0000 1.3
+++ Resource.java 21 Nov 2006 06:07:34 -0000 1.4
@@ -7,16 +7,14 @@
package org.jboss.cache.pojo.test;
-import java.io.Serializable;
-
/**
* Test class for PojoCache using annotation. This represents a special resource
* type that can be declared @Transient. That is, it is neither PojoCacheable nor
* Serializable.
*
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.4 $
*/
- at org.jboss.cache.pojo.annotation.PojoCacheable
+ at org.jboss.cache.pojo.annotation.Replicable
public class Resource
{
String connection = null;
@@ -7,16 +7,14 @@
/**
* Test class for PojoCache using annotation. This represents a special resource
- * type that can be declared @Transient. That is, it is neither PojoCacheable nor
+ * type that can be declared @Transient. That is, it is neither Replicable nor
* Serializable.
*
1.4 +1 -1 JBossCache/tests-50/functional/org/jboss/cache/pojo/test/NetworkElement.java
(In the diff below, changes in quantity of whitespace are not shown.)